Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Talon_csvSourceCSV codec for Talon dataframes.
(* From string *)
let df = Talon_csv.of_string csv_text
(* From file (streaming) *)
let df =
Talon_csv.read "data.csv"
(* To file (streaming) *)
Talon_csv.write "out.csv" dfColumn type specifications. Columns not listed are auto-detected.
val of_string :
?sep:char ->
?names:string list ->
?na_values:string list ->
?dtype_spec:dtype_spec ->
string ->
Talon.tof_string s parses CSV text into a dataframe. The first row is used as column names unless names is provided, in which case all rows are treated as data.
to_string df serializes a dataframe to CSV text. The first row of the output is the column names.
val read :
?sep:char ->
?names:string list ->
?na_values:string list ->
?dtype_spec:dtype_spec ->
string ->
Talon.tread path reads a CSV file into a dataframe, streaming line by line.